# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["UtilDecodeLightningChargeParams"]


class UtilDecodeLightningChargeParams(TypedDict, total=False):
    invoice: str
    """The Charge or Invoice QR code contents"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import util_decode_lightning_charge_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["UtilsResource", "AsyncUtilsResource"]


class UtilsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> UtilsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#accessing-raw-response-data-eg-headers
        """
        return UtilsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> UtilsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#with_streaming_response
        """
        return UtilsResourceWithStreamingResponse(self)

    def check_ip_support(
        self,
        ip: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Verify if a user is coming from a supported region.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not ip:
            raise ValueError(f"Expected a non-empty value for `ip` but received {ip!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/v0/is-supported-region/{ip}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def decode_lightning_charge(
        self,
        *,
        invoice: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Understand the inner properties of a Charge QR code.

        Args:
          invoice: The Charge or Invoice QR code contents

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/v0/decode-invoice",
            body=maybe_transform(
                {"invoice": invoice}, util_decode_lightning_charge_params.UtilDecodeLightningChargeParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list_prod_ips(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Get the official IP addresses of ZBD servers."""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/v0/prod-ips",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve_btc_usd(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Get the latest price for Bitcoin in US Dollars."""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/v0/btcusd",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncUtilsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncUtilsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncUtilsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncUtilsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#with_streaming_response
        """
        return AsyncUtilsResourceWithStreamingResponse(self)

    async def check_ip_support(
        self,
        ip: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Verify if a user is coming from a supported region.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not ip:
            raise ValueError(f"Expected a non-empty value for `ip` but received {ip!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            f"/v0/is-supported-region/{ip}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def decode_lightning_charge(
        self,
        *,
        invoice: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Understand the inner properties of a Charge QR code.

        Args:
          invoice: The Charge or Invoice QR code contents

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/v0/decode-invoice",
            body=await async_maybe_transform(
                {"invoice": invoice}, util_decode_lightning_charge_params.UtilDecodeLightningChargeParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list_prod_ips(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Get the official IP addresses of ZBD servers."""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/v0/prod-ips",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve_btc_usd(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Get the latest price for Bitcoin in US Dollars."""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/v0/btcusd",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class UtilsResourceWithRawResponse:
    def __init__(self, utils: UtilsResource) -> None:
        self._utils = utils

        self.check_ip_support = to_raw_response_wrapper(
            utils.check_ip_support,
        )
        self.decode_lightning_charge = to_raw_response_wrapper(
            utils.decode_lightning_charge,
        )
        self.list_prod_ips = to_raw_response_wrapper(
            utils.list_prod_ips,
        )
        self.retrieve_btc_usd = to_raw_response_wrapper(
            utils.retrieve_btc_usd,
        )


class AsyncUtilsResourceWithRawResponse:
    def __init__(self, utils: AsyncUtilsResource) -> None:
        self._utils = utils

        self.check_ip_support = async_to_raw_response_wrapper(
            utils.check_ip_support,
        )
        self.decode_lightning_charge = async_to_raw_response_wrapper(
            utils.decode_lightning_charge,
        )
        self.list_prod_ips = async_to_raw_response_wrapper(
            utils.list_prod_ips,
        )
        self.retrieve_btc_usd = async_to_raw_response_wrapper(
            utils.retrieve_btc_usd,
        )


class UtilsResourceWithStreamingResponse:
    def __init__(self, utils: UtilsResource) -> None:
        self._utils = utils

        self.check_ip_support = to_streamed_response_wrapper(
            utils.check_ip_support,
        )
        self.decode_lightning_charge = to_streamed_response_wrapper(
            utils.decode_lightning_charge,
        )
        self.list_prod_ips = to_streamed_response_wrapper(
            utils.list_prod_ips,
        )
        self.retrieve_btc_usd = to_streamed_response_wrapper(
            utils.retrieve_btc_usd,
        )


class AsyncUtilsResourceWithStreamingResponse:
    def __init__(self, utils: AsyncUtilsResource) -> None:
        self._utils = utils

        self.check_ip_support = async_to_streamed_response_wrapper(
            utils.check_ip_support,
        )
        self.decode_lightning_charge = async_to_streamed_response_wrapper(
            utils.decode_lightning_charge,
        )
        self.list_prod_ips = async_to_streamed_response_wrapper(
            utils.list_prod_ips,
        )
        self.retrieve_btc_usd = async_to_streamed_response_wrapper(
            utils.retrieve_btc_usd,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["LightningStaticChargeCreateParams"]


class LightningStaticChargeCreateParams(TypedDict, total=False):
    allowed_slots: Annotated[float, PropertyInfo(alias="allowedSlots")]
    """Number of payments this Static Charge can accept"""

    callback_url: Annotated[str, PropertyInfo(alias="callbackUrl")]
    """The endpoint ZBD will POST Charge updates to"""

    description: str
    """Note or comment for this Static Charge (visible to payer)"""

    identifier: str
    """Used for Custom Lightning Addresses (see guide)"""

    internal_id: Annotated[str, PropertyInfo(alias="internalId")]
    """Open metadata string property"""

    max_amount: Annotated[str, PropertyInfo(alias="maxAmount")]
    """Maximum allowed amount for the Static Charge -> in millisatoshis"""

    min_amount: Annotated[str, PropertyInfo(alias="minAmount")]
    """Minimum allowed amount for the Static Charge -> in millisatoshis"""

    success_message: Annotated[str, PropertyInfo(alias="successMessage")]
    """Message displayed to the payer AFTER payment settles.

    Maximum of 144 characters.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["LightningAddressSendPaymentParams"]


class LightningAddressSendPaymentParams(TypedDict, total=False):
    amount: str
    """The amount for the Payment -> in millisatoshis"""

    callback_url: Annotated[str, PropertyInfo(alias="callbackUrl")]
    """The endpoint ZBD will POST Charge updates to"""

    comment: str
    """Note or description of this Payment"""

    internal_id: Annotated[str, PropertyInfo(alias="internalId")]
    """Open metadata string property"""

    ln_address: Annotated[str, PropertyInfo(alias="lnAddress")]
    """The Lightning Address of the intended recipient (e.g. andre@zbd.gg)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from zbdpay import ZbdPayments, AsyncZbdPayments

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestEmailPayments:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_send(self, client: ZbdPayments) -> None:
        email_payment = client.email_payments.send()
        assert email_payment is None

    @pytest.mark.skip()
    @parametrize
    def test_method_send_with_all_params(self, client: ZbdPayments) -> None:
        email_payment = client.email_payments.send(
            amount="string",
            comment="string",
            email="string",
        )
        assert email_payment is None

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_send(self, client: ZbdPayments) -> None:
        response = client.email_payments.with_raw_response.send()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email_payment = response.parse()
        assert email_payment is None

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_send(self, client: ZbdPayments) -> None:
        with client.email_payments.with_streaming_response.send() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            email_payment = response.parse()
            assert email_payment is None

        assert cast(Any, response.is_closed) is True


class TestAsyncEmailPayments:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip()
    @parametrize
    async def test_method_send(self, async_client: AsyncZbdPayments) -> None:
        email_payment = await async_client.email_payments.send()
        assert email_payment is None

    @pytest.mark.skip()
    @parametrize
    async def test_method_send_with_all_params(self, async_client: AsyncZbdPayments) -> None:
        email_payment = await async_client.email_payments.send(
            amount="string",
            comment="string",
            email="string",
        )
        assert email_payment is None

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_send(self, async_client: AsyncZbdPayments) -> None:
        response = await async_client.email_payments.with_raw_response.send()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email_payment = await response.parse()
        assert email_payment is None

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_send(self, async_client: AsyncZbdPayments) -> None:
        async with async_client.email_payments.with_streaming_response.send() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            email_payment = await response.parse()
            assert email_payment is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["KeysendPaymentSendParams"]


class KeysendPaymentSendParams(TypedDict, total=False):
    amount: str
    """The amount for the Payment -> in millisatoshis"""

    callback_url: Annotated[str, PropertyInfo(alias="callbackUrl")]
    """The endpoint ZBD will POST Keysend Payment updates to"""

    metadata: object
    """Open metadata object property"""

    pubkey: str
    """The Public Key for the destination Lightning node"""

    tlv_records: Annotated[List[str], PropertyInfo(alias="tlvRecords")]
    """
    List of TLV records <Expandable title="tlvRecord" defaultOpen>
    <ParamField body="type" type="number" initialValue={123456}> type of the TLV
    record
    """

    value: str
    """value of the TLV record (hex encoded string)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from zbdpay import ZbdPayments, AsyncZbdPayments

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestInternalTransfer:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_initiate(self, client: ZbdPayments) -> None:
        internal_transfer = client.internal_transfer.initiate()
        assert internal_transfer is None

    @pytest.mark.skip()
    @parametrize
    def test_method_initiate_with_all_params(self, client: ZbdPayments) -> None:
        internal_transfer = client.internal_transfer.initiate(
            amount="string",
            receiver_wallet_id="string",
        )
        assert internal_transfer is None

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_initiate(self, client: ZbdPayments) -> None:
        response = client.internal_transfer.with_raw_response.initiate()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        internal_transfer = response.parse()
        assert internal_transfer is None

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_initiate(self, client: ZbdPayments) -> None:
        with client.internal_transfer.with_streaming_response.initiate() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            internal_transfer = response.parse()
            assert internal_transfer is None

        assert cast(Any, response.is_closed) is True


class TestAsyncInternalTransfer:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip()
    @parametrize
    async def test_method_initiate(self, async_client: AsyncZbdPayments) -> None:
        internal_transfer = await async_client.internal_transfer.initiate()
        assert internal_transfer is None

    @pytest.mark.skip()
    @parametrize
    async def test_method_initiate_with_all_params(self, async_client: AsyncZbdPayments) -> None:
        internal_transfer = await async_client.internal_transfer.initiate(
            amount="string",
            receiver_wallet_id="string",
        )
        assert internal_transfer is None

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_initiate(self, async_client: AsyncZbdPayments) -> None:
        response = await async_client.internal_transfer.with_raw_response.initiate()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        internal_transfer = await response.parse()
        assert internal_transfer is None

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_initiate(self, async_client: AsyncZbdPayments) -> None:
        async with async_client.internal_transfer.with_streaming_response.initiate() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            internal_transfer = await response.parse()
            assert internal_transfer is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import lightning_static_charge_create_params, lightning_static_charge_update_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["LightningStaticChargesResource", "AsyncLightningStaticChargesResource"]


class LightningStaticChargesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> LightningStaticChargesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#accessing-raw-response-data-eg-headers
        """
        return LightningStaticChargesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> LightningStaticChargesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#with_streaming_response
        """
        return LightningStaticChargesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        allowed_slots: float | NotGiven = NOT_GIVEN,
        callback_url: str | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        identifier: str | NotGiven = NOT_GIVEN,
        internal_id: str | NotGiven = NOT_GIVEN,
        max_amount: str | NotGiven = NOT_GIVEN,
        min_amount: str | NotGiven = NOT_GIVEN,
        success_message: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Start accepting payments on Lightning with Static QR codes.

        Args:
          allowed_slots: Number of payments this Static Charge can accept

          callback_url: The endpoint ZBD will POST Charge updates to

          description: Note or comment for this Static Charge (visible to payer)

          identifier: Used for Custom Lightning Addresses (see guide)

          internal_id: Open metadata string property

          max_amount: Maximum allowed amount for the Static Charge -> in millisatoshis

          min_amount: Minimum allowed amount for the Static Charge -> in millisatoshis

          success_message: Message displayed to the payer AFTER payment settles. Maximum of 144 characters.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/v0/static-charges",
            body=maybe_transform(
                {
                    "allowed_slots": allowed_slots,
                    "callback_url": callback_url,
                    "description": description,
                    "identifier": identifier,
                    "internal_id": internal_id,
                    "max_amount": max_amount,
                    "min_amount": min_amount,
                    "success_message": success_message,
                },
                lightning_static_charge_create_params.LightningStaticChargeCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Retrieve all data about a single Static Charge.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/v0/static-charges/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def update(
        self,
        id: str,
        *,
        allowed_slots: float | NotGiven = NOT_GIVEN,
        callback_url: str | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        internal_id: str | NotGiven = NOT_GIVEN,
        max_amount: str | NotGiven = NOT_GIVEN,
        min_amount: str | NotGiven = NOT_GIVEN,
        success_message: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Change the configuration of a Static Charge QR code.

        Args:
          allowed_slots: Number of payments this Static Charge can accept

          callback_url: The endpoint ZBD will POST Charge updates to

          description: Note or comment for this Static Charge (visible to payer)

          internal_id: Open metadata string property

          max_amount: Maximum allowed amount for the Static Charge -> in millisatoshis

          min_amount: Minimum allowed amount for the Static Charge -> in millisatoshis

          success_message: Message displayed to the payer AFTER payment settles

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._patch(
            f"/v0/static-charges/{id}",
            body=maybe_transform(
                {
                    "allowed_slots": allowed_slots,
                    "callback_url": callback_url,
                    "description": description,
                    "internal_id": internal_id,
                    "max_amount": max_amount,
                    "min_amount": min_amount,
                    "success_message": success_message,
                },
                lightning_static_charge_update_params.LightningStaticChargeUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncLightningStaticChargesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncLightningStaticChargesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncLightningStaticChargesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncLightningStaticChargesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#with_streaming_response
        """
        return AsyncLightningStaticChargesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        allowed_slots: float | NotGiven = NOT_GIVEN,
        callback_url: str | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        identifier: str | NotGiven = NOT_GIVEN,
        internal_id: str | NotGiven = NOT_GIVEN,
        max_amount: str | NotGiven = NOT_GIVEN,
        min_amount: str | NotGiven = NOT_GIVEN,
        success_message: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Start accepting payments on Lightning with Static QR codes.

        Args:
          allowed_slots: Number of payments this Static Charge can accept

          callback_url: The endpoint ZBD will POST Charge updates to

          description: Note or comment for this Static Charge (visible to payer)

          identifier: Used for Custom Lightning Addresses (see guide)

          internal_id: Open metadata string property

          max_amount: Maximum allowed amount for the Static Charge -> in millisatoshis

          min_amount: Minimum allowed amount for the Static Charge -> in millisatoshis

          success_message: Message displayed to the payer AFTER payment settles. Maximum of 144 characters.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/v0/static-charges",
            body=await async_maybe_transform(
                {
                    "allowed_slots": allowed_slots,
                    "callback_url": callback_url,
                    "description": description,
                    "identifier": identifier,
                    "internal_id": internal_id,
                    "max_amount": max_amount,
                    "min_amount": min_amount,
                    "success_message": success_message,
                },
                lightning_static_charge_create_params.LightningStaticChargeCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Retrieve all data about a single Static Charge.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            f"/v0/static-charges/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def update(
        self,
        id: str,
        *,
        allowed_slots: float | NotGiven = NOT_GIVEN,
        callback_url: str | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        internal_id: str | NotGiven = NOT_GIVEN,
        max_amount: str | NotGiven = NOT_GIVEN,
        min_amount: str | NotGiven = NOT_GIVEN,
        success_message: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Change the configuration of a Static Charge QR code.

        Args:
          allowed_slots: Number of payments this Static Charge can accept

          callback_url: The endpoint ZBD will POST Charge updates to

          description: Note or comment for this Static Charge (visible to payer)

          internal_id: Open metadata string property

          max_amount: Maximum allowed amount for the Static Charge -> in millisatoshis

          min_amount: Minimum allowed amount for the Static Charge -> in millisatoshis

          success_message: Message displayed to the payer AFTER payment settles

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._patch(
            f"/v0/static-charges/{id}",
            body=await async_maybe_transform(
                {
                    "allowed_slots": allowed_slots,
                    "callback_url": callback_url,
                    "description": description,
                    "internal_id": internal_id,
                    "max_amount": max_amount,
                    "min_amount": min_amount,
                    "success_message": success_message,
                },
                lightning_static_charge_update_params.LightningStaticChargeUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class LightningStaticChargesResourceWithRawResponse:
    def __init__(self, lightning_static_charges: LightningStaticChargesResource) -> None:
        self._lightning_static_charges = lightning_static_charges

        self.create = to_raw_response_wrapper(
            lightning_static_charges.create,
        )
        self.retrieve = to_raw_response_wrapper(
            lightning_static_charges.retrieve,
        )
        self.update = to_raw_response_wrapper(
            lightning_static_charges.update,
        )


class AsyncLightningStaticChargesResourceWithRawResponse:
    def __init__(self, lightning_static_charges: AsyncLightningStaticChargesResource) -> None:
        self._lightning_static_charges = lightning_static_charges

        self.create = async_to_raw_response_wrapper(
            lightning_static_charges.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            lightning_static_charges.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            lightning_static_charges.update,
        )


class LightningStaticChargesResourceWithStreamingResponse:
    def __init__(self, lightning_static_charges: LightningStaticChargesResource) -> None:
        self._lightning_static_charges = lightning_static_charges

        self.create = to_streamed_response_wrapper(
            lightning_static_charges.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            lightning_static_charges.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            lightning_static_charges.update,
        )


class AsyncLightningStaticChargesResourceWithStreamingResponse:
    def __init__(self, lightning_static_charges: AsyncLightningStaticChargesResource) -> None:
        self._lightning_static_charges = lightning_static_charges

        self.create = async_to_streamed_response_wrapper(
            lightning_static_charges.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            lightning_static_charges.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            lightning_static_charges.update,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import lightning_payment_send_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["LightningPaymentsResource", "AsyncLightningPaymentsResource"]


class LightningPaymentsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> LightningPaymentsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#accessing-raw-response-data-eg-headers
        """
        return LightningPaymentsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> LightningPaymentsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#with_streaming_response
        """
        return LightningPaymentsResourceWithStreamingResponse(self)

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Retrieve all data about a single Payment.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/v0/payments/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def send(
        self,
        *,
        amount: str | NotGiven = NOT_GIVEN,
        callback_url: str | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        internal_id: str | NotGiven = NOT_GIVEN,
        invoice: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Start sending instant Bitcoin payments through the ZBD API.

        Args:
          amount: Amount to be paid to this Charge/Invoice -> in millisatoshis _(only valid if
              Amountless Invoice)_

          callback_url: The endpoint ZBD will POST Payment updates to

          description: Note or comment for this Payment

          internal_id: Open metadata string property

          invoice: Lightning Network Payment Request / Charge

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/v0/payments",
            body=maybe_transform(
                {
                    "amount": amount,
                    "callback_url": callback_url,
                    "description": description,
                    "internal_id": internal_id,
                    "invoice": invoice,
                },
                lightning_payment_send_params.LightningPaymentSendParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncLightningPaymentsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncLightningPaymentsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncLightningPaymentsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncLightningPaymentsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#with_streaming_response
        """
        return AsyncLightningPaymentsResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Retrieve all data about a single Payment.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            f"/v0/payments/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def send(
        self,
        *,
        amount: str | NotGiven = NOT_GIVEN,
        callback_url: str | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        internal_id: str | NotGiven = NOT_GIVEN,
        invoice: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Start sending instant Bitcoin payments through the ZBD API.

        Args:
          amount: Amount to be paid to this Charge/Invoice -> in millisatoshis _(only valid if
              Amountless Invoice)_

          callback_url: The endpoint ZBD will POST Payment updates to

          description: Note or comment for this Payment

          internal_id: Open metadata string property

          invoice: Lightning Network Payment Request / Charge

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/v0/payments",
            body=await async_maybe_transform(
                {
                    "amount": amount,
                    "callback_url": callback_url,
                    "description": description,
                    "internal_id": internal_id,
                    "invoice": invoice,
                },
                lightning_payment_send_params.LightningPaymentSendParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class LightningPaymentsResourceWithRawResponse:
    def __init__(self, lightning_payments: LightningPaymentsResource) -> None:
        self._lightning_payments = lightning_payments

        self.retrieve = to_raw_response_wrapper(
            lightning_payments.retrieve,
        )
        self.send = to_raw_response_wrapper(
            lightning_payments.send,
        )


class AsyncLightningPaymentsResourceWithRawResponse:
    def __init__(self, lightning_payments: AsyncLightningPaymentsResource) -> None:
        self._lightning_payments = lightning_payments

        self.retrieve = async_to_raw_response_wrapper(
            lightning_payments.retrieve,
        )
        self.send = async_to_raw_response_wrapper(
            lightning_payments.send,
        )


class LightningPaymentsResourceWithStreamingResponse:
    def __init__(self, lightning_payments: LightningPaymentsResource) -> None:
        self._lightning_payments = lightning_payments

        self.retrieve = to_streamed_response_wrapper(
            lightning_payments.retrieve,
        )
        self.send = to_streamed_response_wrapper(
            lightning_payments.send,
        )


class AsyncLightningPaymentsResourceWithStreamingResponse:
    def __init__(self, lightning_payments: AsyncLightningPaymentsResource) -> None:
        self._lightning_payments = lightning_payments

        self.retrieve = async_to_streamed_response_wrapper(
            lightning_payments.retrieve,
        )
        self.send = async_to_streamed_response_wrapper(
            lightning_payments.send,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import internal_transfer_initiate_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["InternalTransferResource", "AsyncInternalTransferResource"]


class InternalTransferResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> InternalTransferResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#accessing-raw-response-data-eg-headers
        """
        return InternalTransferResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> InternalTransferResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#with_streaming_response
        """
        return InternalTransferResourceWithStreamingResponse(self)

    def initiate(
        self,
        *,
        amount: str | NotGiven = NOT_GIVEN,
        receiver_wallet_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Performs a transfer of funds between two Projects.

        Args:
          amount: The amount to be transferred -> in millisatoshis

          receiver_wallet_id: The Wallet ID of the recipient Project

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/v0/internal-transfer",
            body=maybe_transform(
                {
                    "amount": amount,
                    "receiver_wallet_id": receiver_wallet_id,
                },
                internal_transfer_initiate_params.InternalTransferInitiateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncInternalTransferResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncInternalTransferResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncInternalTransferResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncInternalTransferResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#with_streaming_response
        """
        return AsyncInternalTransferResourceWithStreamingResponse(self)

    async def initiate(
        self,
        *,
        amount: str | NotGiven = NOT_GIVEN,
        receiver_wallet_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Performs a transfer of funds between two Projects.

        Args:
          amount: The amount to be transferred -> in millisatoshis

          receiver_wallet_id: The Wallet ID of the recipient Project

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/v0/internal-transfer",
            body=await async_maybe_transform(
                {
                    "amount": amount,
                    "receiver_wallet_id": receiver_wallet_id,
                },
                internal_transfer_initiate_params.InternalTransferInitiateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class InternalTransferResourceWithRawResponse:
    def __init__(self, internal_transfer: InternalTransferResource) -> None:
        self._internal_transfer = internal_transfer

        self.initiate = to_raw_response_wrapper(
            internal_transfer.initiate,
        )


class AsyncInternalTransferResourceWithRawResponse:
    def __init__(self, internal_transfer: AsyncInternalTransferResource) -> None:
        self._internal_transfer = internal_transfer

        self.initiate = async_to_raw_response_wrapper(
            internal_transfer.initiate,
        )


class InternalTransferResourceWithStreamingResponse:
    def __init__(self, internal_transfer: InternalTransferResource) -> None:
        self._internal_transfer = internal_transfer

        self.initiate = to_streamed_response_wrapper(
            internal_transfer.initiate,
        )


class AsyncInternalTransferResourceWithStreamingResponse:
    def __init__(self, internal_transfer: AsyncInternalTransferResource) -> None:
        self._internal_transfer = internal_transfer

        self.initiate = async_to_streamed_response_wrapper(
            internal_transfer.initiate,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["LightningPaymentSendParams"]


class LightningPaymentSendParams(TypedDict, total=False):
    amount: str
    """
    Amount to be paid to this Charge/Invoice -> in millisatoshis _(only valid if
    Amountless Invoice)_
    """

    callback_url: Annotated[str, PropertyInfo(alias="callbackUrl")]
    """The endpoint ZBD will POST Payment updates to"""

    description: str
    """Note or comment for this Payment"""

    internal_id: Annotated[str, PropertyInfo(alias="internalId")]
    """Open metadata string property"""

    invoice: str
    """Lightning Network Payment Request / Charge"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import email_payment_send_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["EmailPaymentsResource", "AsyncEmailPaymentsResource"]


class EmailPaymentsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> EmailPaymentsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#accessing-raw-response-data-eg-headers
        """
        return EmailPaymentsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> EmailPaymentsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#with_streaming_response
        """
        return EmailPaymentsResourceWithStreamingResponse(self)

    def send(
        self,
        *,
        amount: str | NotGiven = NOT_GIVEN,
        comment: str | NotGiven = NOT_GIVEN,
        email: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Send instant Bitcoin payments to any email.

        Args:
          amount: The amount for the Payment -> in millisatoshis

          comment: Note / description of this Payment (may be shown to recipient)

          email: The Email of the intended recipient (e.g. info@zebedee.io)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/v0/email/send-payment",
            body=maybe_transform(
                {
                    "amount": amount,
                    "comment": comment,
                    "email": email,
                },
                email_payment_send_params.EmailPaymentSendParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncEmailPaymentsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncEmailPaymentsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncEmailPaymentsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncEmailPaymentsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#with_streaming_response
        """
        return AsyncEmailPaymentsResourceWithStreamingResponse(self)

    async def send(
        self,
        *,
        amount: str | NotGiven = NOT_GIVEN,
        comment: str | NotGiven = NOT_GIVEN,
        email: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Send instant Bitcoin payments to any email.

        Args:
          amount: The amount for the Payment -> in millisatoshis

          comment: Note / description of this Payment (may be shown to recipient)

          email: The Email of the intended recipient (e.g. info@zebedee.io)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/v0/email/send-payment",
            body=await async_maybe_transform(
                {
                    "amount": amount,
                    "comment": comment,
                    "email": email,
                },
                email_payment_send_params.EmailPaymentSendParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class EmailPaymentsResourceWithRawResponse:
    def __init__(self, email_payments: EmailPaymentsResource) -> None:
        self._email_payments = email_payments

        self.send = to_raw_response_wrapper(
            email_payments.send,
        )


class AsyncEmailPaymentsResourceWithRawResponse:
    def __init__(self, email_payments: AsyncEmailPaymentsResource) -> None:
        self._email_payments = email_payments

        self.send = async_to_raw_response_wrapper(
            email_payments.send,
        )


class EmailPaymentsResourceWithStreamingResponse:
    def __init__(self, email_payments: EmailPaymentsResource) -> None:
        self._email_payments = email_payments

        self.send = to_streamed_response_wrapper(
            email_payments.send,
        )


class AsyncEmailPaymentsResourceWithStreamingResponse:
    def __init__(self, email_payments: AsyncEmailPaymentsResource) -> None:
        self._email_payments = email_payments

        self.send = async_to_streamed_response_wrapper(
            email_payments.send,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from zbdpay import ZbdPayments, AsyncZbdPayments

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestUtils:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_check_ip_support(self, client: ZbdPayments) -> None:
        util = client.utils.check_ip_support(
            "ip",
        )
        assert util is None

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_check_ip_support(self, client: ZbdPayments) -> None:
        response = client.utils.with_raw_response.check_ip_support(
            "ip",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        util = response.parse()
        assert util is None

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_check_ip_support(self, client: ZbdPayments) -> None:
        with client.utils.with_streaming_response.check_ip_support(
            "ip",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            util = response.parse()
            assert util is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_check_ip_support(self, client: ZbdPayments) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `ip` but received ''"):
            client.utils.with_raw_response.check_ip_support(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_decode_lightning_charge(self, client: ZbdPayments) -> None:
        util = client.utils.decode_lightning_charge()
        assert util is None

    @pytest.mark.skip()
    @parametrize
    def test_method_decode_lightning_charge_with_all_params(self, client: ZbdPayments) -> None:
        util = client.utils.decode_lightning_charge(
            invoice="string",
        )
        assert util is None

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_decode_lightning_charge(self, client: ZbdPayments) -> None:
        response = client.utils.with_raw_response.decode_lightning_charge()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        util = response.parse()
        assert util is None

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_decode_lightning_charge(self, client: ZbdPayments) -> None:
        with client.utils.with_streaming_response.decode_lightning_charge() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            util = response.parse()
            assert util is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_list_prod_ips(self, client: ZbdPayments) -> None:
        util = client.utils.list_prod_ips()
        assert util is None

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_list_prod_ips(self, client: ZbdPayments) -> None:
        response = client.utils.with_raw_response.list_prod_ips()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        util = response.parse()
        assert util is None

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_list_prod_ips(self, client: ZbdPayments) -> None:
        with client.utils.with_streaming_response.list_prod_ips() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            util = response.parse()
            assert util is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve_btc_usd(self, client: ZbdPayments) -> None:
        util = client.utils.retrieve_btc_usd()
        assert util is None

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_retrieve_btc_usd(self, client: ZbdPayments) -> None:
        response = client.utils.with_raw_response.retrieve_btc_usd()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        util = response.parse()
        assert util is None

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_retrieve_btc_usd(self, client: ZbdPayments) -> None:
        with client.utils.with_streaming_response.retrieve_btc_usd() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            util = response.parse()
            assert util is None

        assert cast(Any, response.is_closed) is True


class TestAsyncUtils:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip()
    @parametrize
    async def test_method_check_ip_support(self, async_client: AsyncZbdPayments) -> None:
        util = await async_client.utils.check_ip_support(
            "ip",
        )
        assert util is None

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_check_ip_support(self, async_client: AsyncZbdPayments) -> None:
        response = await async_client.utils.with_raw_response.check_ip_support(
            "ip",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        util = await response.parse()
        assert util is None

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_check_ip_support(self, async_client: AsyncZbdPayments) -> None:
        async with async_client.utils.with_streaming_response.check_ip_support(
            "ip",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            util = await response.parse()
            assert util is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_check_ip_support(self, async_client: AsyncZbdPayments) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `ip` but received ''"):
            await async_client.utils.with_raw_response.check_ip_support(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_decode_lightning_charge(self, async_client: AsyncZbdPayments) -> None:
        util = await async_client.utils.decode_lightning_charge()
        assert util is None

    @pytest.mark.skip()
    @parametrize
    async def test_method_decode_lightning_charge_with_all_params(self, async_client: AsyncZbdPayments) -> None:
        util = await async_client.utils.decode_lightning_charge(
            invoice="string",
        )
        assert util is None

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_decode_lightning_charge(self, async_client: AsyncZbdPayments) -> None:
        response = await async_client.utils.with_raw_response.decode_lightning_charge()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        util = await response.parse()
        assert util is None

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_decode_lightning_charge(self, async_client: AsyncZbdPayments) -> None:
        async with async_client.utils.with_streaming_response.decode_lightning_charge() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            util = await response.parse()
            assert util is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_list_prod_ips(self, async_client: AsyncZbdPayments) -> None:
        util = await async_client.utils.list_prod_ips()
        assert util is None

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_list_prod_ips(self, async_client: AsyncZbdPayments) -> None:
        response = await async_client.utils.with_raw_response.list_prod_ips()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        util = await response.parse()
        assert util is None

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_list_prod_ips(self, async_client: AsyncZbdPayments) -> None:
        async with async_client.utils.with_streaming_response.list_prod_ips() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            util = await response.parse()
            assert util is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve_btc_usd(self, async_client: AsyncZbdPayments) -> None:
        util = await async_client.utils.retrieve_btc_usd()
        assert util is None

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_retrieve_btc_usd(self, async_client: AsyncZbdPayments) -> None:
        response = await async_client.utils.with_raw_response.retrieve_btc_usd()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        util = await response.parse()
        assert util is None

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_retrieve_btc_usd(self, async_client: AsyncZbdPayments) -> None:
        async with async_client.utils.with_streaming_response.retrieve_btc_usd() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            util = await response.parse()
            assert util is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from zbdpay import ZbdPayments, AsyncZbdPayments

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestLightningStaticCharges:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create(self, client: ZbdPayments) -> None:
        lightning_static_charge = client.lightning_static_charges.create()
        assert lightning_static_charge is None

    @pytest.mark.skip()
    @parametrize
    def test_method_create_with_all_params(self, client: ZbdPayments) -> None:
        lightning_static_charge = client.lightning_static_charges.create(
            allowed_slots=123,
            callback_url="string",
            description="string",
            identifier="string",
            internal_id="string",
            max_amount="string",
            min_amount="string",
            success_message="string",
        )
        assert lightning_static_charge is None

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_create(self, client: ZbdPayments) -> None:
        response = client.lightning_static_charges.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        lightning_static_charge = response.parse()
        assert lightning_static_charge is None

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_create(self, client: ZbdPayments) -> None:
        with client.lightning_static_charges.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            lightning_static_charge = response.parse()
            assert lightning_static_charge is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve(self, client: ZbdPayments) -> None:
        lightning_static_charge = client.lightning_static_charges.retrieve(
            "id",
        )
        assert lightning_static_charge is None

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_retrieve(self, client: ZbdPayments) -> None:
        response = client.lightning_static_charges.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        lightning_static_charge = response.parse()
        assert lightning_static_charge is None

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_retrieve(self, client: ZbdPayments) -> None:
        with client.lightning_static_charges.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            lightning_static_charge = response.parse()
            assert lightning_static_charge is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_retrieve(self, client: ZbdPayments) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.lightning_static_charges.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_update(self, client: ZbdPayments) -> None:
        lightning_static_charge = client.lightning_static_charges.update(
            id="id",
        )
        assert lightning_static_charge is None

    @pytest.mark.skip()
    @parametrize
    def test_method_update_with_all_params(self, client: ZbdPayments) -> None:
        lightning_static_charge = client.lightning_static_charges.update(
            id="id",
            allowed_slots=123,
            callback_url="string",
            description="string",
            internal_id="string",
            max_amount="string",
            min_amount="string",
            success_message="string",
        )
        assert lightning_static_charge is None

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_update(self, client: ZbdPayments) -> None:
        response = client.lightning_static_charges.with_raw_response.update(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        lightning_static_charge = response.parse()
        assert lightning_static_charge is None

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_update(self, client: ZbdPayments) -> None:
        with client.lightning_static_charges.with_streaming_response.update(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            lightning_static_charge = response.parse()
            assert lightning_static_charge is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_update(self, client: ZbdPayments) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.lightning_static_charges.with_raw_response.update(
                id="",
            )


class TestAsyncLightningStaticCharges:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip()
    @parametrize
    async def test_method_create(self, async_client: AsyncZbdPayments) -> None:
        lightning_static_charge = await async_client.lightning_static_charges.create()
        assert lightning_static_charge is None

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncZbdPayments) -> None:
        lightning_static_charge = await async_client.lightning_static_charges.create(
            allowed_slots=123,
            callback_url="string",
            description="string",
            identifier="string",
            internal_id="string",
            max_amount="string",
            min_amount="string",
            success_message="string",
        )
        assert lightning_static_charge is None

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncZbdPayments) -> None:
        response = await async_client.lightning_static_charges.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        lightning_static_charge = await response.parse()
        assert lightning_static_charge is None

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncZbdPayments) -> None:
        async with async_client.lightning_static_charges.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            lightning_static_charge = await response.parse()
            assert lightning_static_charge is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncZbdPayments) -> None:
        lightning_static_charge = await async_client.lightning_static_charges.retrieve(
            "id",
        )
        assert lightning_static_charge is None

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncZbdPayments) -> None:
        response = await async_client.lightning_static_charges.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        lightning_static_charge = await response.parse()
        assert lightning_static_charge is None

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncZbdPayments) -> None:
        async with async_client.lightning_static_charges.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            lightning_static_charge = await response.parse()
            assert lightning_static_charge is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncZbdPayments) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.lightning_static_charges.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_update(self, async_client: AsyncZbdPayments) -> None:
        lightning_static_charge = await async_client.lightning_static_charges.update(
            id="id",
        )
        assert lightning_static_charge is None

    @pytest.mark.skip()
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncZbdPayments) -> None:
        lightning_static_charge = await async_client.lightning_static_charges.update(
            id="id",
            allowed_slots=123,
            callback_url="string",
            description="string",
            internal_id="string",
            max_amount="string",
            min_amount="string",
            success_message="string",
        )
        assert lightning_static_charge is None

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncZbdPayments) -> None:
        response = await async_client.lightning_static_charges.with_raw_response.update(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        lightning_static_charge = await response.parse()
        assert lightning_static_charge is None

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncZbdPayments) -> None:
        async with async_client.lightning_static_charges.with_streaming_response.update(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            lightning_static_charge = await response.parse()
            assert lightning_static_charge is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_update(self, async_client: AsyncZbdPayments) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.lightning_static_charges.with_raw_response.update(
                id="",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List

import httpx

from ..types import keysend_payment_send_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["KeysendPaymentsResource", "AsyncKeysendPaymentsResource"]


class KeysendPaymentsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> KeysendPaymentsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#accessing-raw-response-data-eg-headers
        """
        return KeysendPaymentsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> KeysendPaymentsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#with_streaming_response
        """
        return KeysendPaymentsResourceWithStreamingResponse(self)

    def send(
        self,
        *,
        amount: str | NotGiven = NOT_GIVEN,
        callback_url: str | NotGiven = NOT_GIVEN,
        metadata: object | NotGiven = NOT_GIVEN,
        pubkey: str | NotGiven = NOT_GIVEN,
        tlv_records: List[str] | NotGiven = NOT_GIVEN,
        value: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Start sending Keysend payments on the Lightning Network.

        Args:
          amount: The amount for the Payment -> in millisatoshis

          callback_url: The endpoint ZBD will POST Keysend Payment updates to

          metadata: Open metadata object property

          pubkey: The Public Key for the destination Lightning node

          tlv_records: List of TLV records <Expandable title="tlvRecord" defaultOpen>
              <ParamField body="type" type="number" initialValue={123456}> type of the TLV
              record

          value: value of the TLV record (hex encoded string)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/v0/keysend-payment",
            body=maybe_transform(
                {
                    "amount": amount,
                    "callback_url": callback_url,
                    "metadata": metadata,
                    "pubkey": pubkey,
                    "tlv_records": tlv_records,
                    "value": value,
                },
                keysend_payment_send_params.KeysendPaymentSendParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncKeysendPaymentsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncKeysendPaymentsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncKeysendPaymentsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncKeysendPaymentsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#with_streaming_response
        """
        return AsyncKeysendPaymentsResourceWithStreamingResponse(self)

    async def send(
        self,
        *,
        amount: str | NotGiven = NOT_GIVEN,
        callback_url: str | NotGiven = NOT_GIVEN,
        metadata: object | NotGiven = NOT_GIVEN,
        pubkey: str | NotGiven = NOT_GIVEN,
        tlv_records: List[str] | NotGiven = NOT_GIVEN,
        value: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Start sending Keysend payments on the Lightning Network.

        Args:
          amount: The amount for the Payment -> in millisatoshis

          callback_url: The endpoint ZBD will POST Keysend Payment updates to

          metadata: Open metadata object property

          pubkey: The Public Key for the destination Lightning node

          tlv_records: List of TLV records <Expandable title="tlvRecord" defaultOpen>
              <ParamField body="type" type="number" initialValue={123456}> type of the TLV
              record

          value: value of the TLV record (hex encoded string)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/v0/keysend-payment",
            body=await async_maybe_transform(
                {
                    "amount": amount,
                    "callback_url": callback_url,
                    "metadata": metadata,
                    "pubkey": pubkey,
                    "tlv_records": tlv_records,
                    "value": value,
                },
                keysend_payment_send_params.KeysendPaymentSendParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class KeysendPaymentsResourceWithRawResponse:
    def __init__(self, keysend_payments: KeysendPaymentsResource) -> None:
        self._keysend_payments = keysend_payments

        self.send = to_raw_response_wrapper(
            keysend_payments.send,
        )


class AsyncKeysendPaymentsResourceWithRawResponse:
    def __init__(self, keysend_payments: AsyncKeysendPaymentsResource) -> None:
        self._keysend_payments = keysend_payments

        self.send = async_to_raw_response_wrapper(
            keysend_payments.send,
        )


class KeysendPaymentsResourceWithStreamingResponse:
    def __init__(self, keysend_payments: KeysendPaymentsResource) -> None:
        self._keysend_payments = keysend_payments

        self.send = to_streamed_response_wrapper(
            keysend_payments.send,
        )


class AsyncKeysendPaymentsResourceWithStreamingResponse:
    def __init__(self, keysend_payments: AsyncKeysendPaymentsResource) -> None:
        self._keysend_payments = keysend_payments

        self.send = async_to_streamed_response_wrapper(
            keysend_payments.send,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["GamertagSendPaymentParams"]


class GamertagSendPaymentParams(TypedDict, total=False):
    amount: str
    """The amount for the Payment -> in millisatoshis"""

    description: str
    """Note or comment for this Payment (visible to recipient)"""

    gamertag: str
    """Destination ZBD Gamertag"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["GamertagCreateChargeParams"]


class GamertagCreateChargeParams(TypedDict, total=False):
    amount: str
    """The amount for the Payment -> in millisatoshis"""

    callback_url: Annotated[str, PropertyInfo(alias="callbackUrl")]
    """The endpoint ZBD will POST Charge updates to"""

    description: str
    """Note or comment for this Payment (visible to recipient)"""

    expires_in: Annotated[float, PropertyInfo(alias="expiresIn")]
    """Time until Charge expiration -> in seconds"""

    gamertag: str
    """Destination ZBD Gamertag"""

    internal_id: Annotated[str, PropertyInfo(alias="internalId")]
    """Open metadata string property"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["EmailPaymentSendParams"]


class EmailPaymentSendParams(TypedDict, total=False):
    amount: str
    """The amount for the Payment -> in millisatoshis"""

    comment: str
    """Note / description of this Payment (may be shown to recipient)"""

    email: str
    """The Email of the intended recipient (e.g. info@zebedee.io)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .utils import (
    UtilsResource,
    AsyncUtilsResource,
    UtilsResourceWithRawResponse,
    AsyncUtilsResourceWithRawResponse,
    UtilsResourceWithStreamingResponse,
    AsyncUtilsResourceWithStreamingResponse,
)
from .oauth2 import (
    Oauth2Resource,
    AsyncOauth2Resource,
    Oauth2ResourceWithRawResponse,
    AsyncOauth2ResourceWithRawResponse,
    Oauth2ResourceWithStreamingResponse,
    AsyncOauth2ResourceWithStreamingResponse,
)
from .wallet import (
    WalletResource,
    AsyncWalletResource,
    WalletResourceWithRawResponse,
    AsyncWalletResourceWithRawResponse,
    WalletResourceWithStreamingResponse,
    AsyncWalletResourceWithStreamingResponse,
)
from .vouchers import (
    VouchersResource,
    AsyncVouchersResource,
    VouchersResourceWithRawResponse,
    AsyncVouchersResourceWithRawResponse,
    VouchersResourceWithStreamingResponse,
    AsyncVouchersResourceWithStreamingResponse,
)
from .gamertags import (
    GamertagsResource,
    AsyncGamertagsResource,
    GamertagsResourceWithRawResponse,
    AsyncGamertagsResourceWithRawResponse,
    GamertagsResourceWithStreamingResponse,
    AsyncGamertagsResourceWithStreamingResponse,
)
from .email_payments import (
    EmailPaymentsResource,
    AsyncEmailPaymentsResource,
    EmailPaymentsResourceWithRawResponse,
    AsyncEmailPaymentsResourceWithRawResponse,
    EmailPaymentsResourceWithStreamingResponse,
    AsyncEmailPaymentsResourceWithStreamingResponse,
)
from .keysend_payments import (
    KeysendPaymentsResource,
    AsyncKeysendPaymentsResource,
    KeysendPaymentsResourceWithRawResponse,
    AsyncKeysendPaymentsResourceWithRawResponse,
    KeysendPaymentsResourceWithStreamingResponse,
    AsyncKeysendPaymentsResourceWithStreamingResponse,
)
from .internal_transfer import (
    InternalTransferResource,
    AsyncInternalTransferResource,
    InternalTransferResourceWithRawResponse,
    AsyncInternalTransferResourceWithRawResponse,
    InternalTransferResourceWithStreamingResponse,
    AsyncInternalTransferResourceWithStreamingResponse,
)
from .lightning_address import (
    LightningAddressResource,
    AsyncLightningAddressResource,
    LightningAddressResourceWithRawResponse,
    AsyncLightningAddressResourceWithRawResponse,
    LightningAddressResourceWithStreamingResponse,
    AsyncLightningAddressResourceWithStreamingResponse,
)
from .lightning_charges import (
    LightningChargesResource,
    AsyncLightningChargesResource,
    LightningChargesResourceWithRawResponse,
    AsyncLightningChargesResourceWithRawResponse,
    LightningChargesResourceWithStreamingResponse,
    AsyncLightningChargesResourceWithStreamingResponse,
)
from .lightning_payments import (
    LightningPaymentsResource,
    AsyncLightningPaymentsResource,
    LightningPaymentsResourceWithRawResponse,
    AsyncLightningPaymentsResourceWithRawResponse,
    LightningPaymentsResourceWithStreamingResponse,
    AsyncLightningPaymentsResourceWithStreamingResponse,
)
from .withdrawal_requests import (
    WithdrawalRequestsResource,
    AsyncWithdrawalRequestsResource,
    WithdrawalRequestsResourceWithRawResponse,
    AsyncWithdrawalRequestsResourceWithRawResponse,
    WithdrawalRequestsResourceWithStreamingResponse,
    AsyncWithdrawalRequestsResourceWithStreamingResponse,
)
from .lightning_static_charges import (
    LightningStaticChargesResource,
    AsyncLightningStaticChargesResource,
    LightningStaticChargesResourceWithRawResponse,
    AsyncLightningStaticChargesResourceWithRawResponse,
    LightningStaticChargesResourceWithStreamingResponse,
    AsyncLightningStaticChargesResourceWithStreamingResponse,
)

__all__ = [
    "GamertagsResource",
    "AsyncGamertagsResource",
    "GamertagsResourceWithRawResponse",
    "AsyncGamertagsResourceWithRawResponse",
    "GamertagsResourceWithStreamingResponse",
    "AsyncGamertagsResourceWithStreamingResponse",
    "LightningChargesResource",
    "AsyncLightningChargesResource",
    "LightningChargesResourceWithRawResponse",
    "AsyncLightningChargesResourceWithRawResponse",
    "LightningChargesResourceWithStreamingResponse",
    "AsyncLightningChargesResourceWithStreamingResponse",
    "InternalTransferResource",
    "AsyncInternalTransferResource",
    "InternalTransferResourceWithRawResponse",
    "AsyncInternalTransferResourceWithRawResponse",
    "InternalTransferResourceWithStreamingResponse",
    "AsyncInternalTransferResourceWithStreamingResponse",
    "LightningAddressResource",
    "AsyncLightningAddressResource",
    "LightningAddressResourceWithRawResponse",
    "AsyncLightningAddressResourceWithRawResponse",
    "LightningAddressResourceWithStreamingResponse",
    "AsyncLightningAddressResourceWithStreamingResponse",
    "LightningStaticChargesResource",
    "AsyncLightningStaticChargesResource",
    "LightningStaticChargesResourceWithRawResponse",
    "AsyncLightningStaticChargesResourceWithRawResponse",
    "LightningStaticChargesResourceWithStreamingResponse",
    "AsyncLightningStaticChargesResourceWithStreamingResponse",
    "VouchersResource",
    "AsyncVouchersResource",
    "VouchersResourceWithRawResponse",
    "AsyncVouchersResourceWithRawResponse",
    "VouchersResourceWithStreamingResponse",
    "AsyncVouchersResourceWithStreamingResponse",
    "WithdrawalRequestsResource",
    "AsyncWithdrawalRequestsResource",
    "WithdrawalRequestsResourceWithRawResponse",
    "AsyncWithdrawalRequestsResourceWithRawResponse",
    "WithdrawalRequestsResourceWithStreamingResponse",
    "AsyncWithdrawalRequestsResourceWithStreamingResponse",
    "LightningPaymentsResource",
    "AsyncLightningPaymentsResource",
    "LightningPaymentsResourceWithRawResponse",
    "AsyncLightningPaymentsResourceWithRawResponse",
    "LightningPaymentsResourceWithStreamingResponse",
    "AsyncLightningPaymentsResourceWithStreamingResponse",
    "WalletResource",
    "AsyncWalletResource",
    "WalletResourceWithRawResponse",
    "AsyncWalletResourceWithRawResponse",
    "WalletResourceWithStreamingResponse",
    "AsyncWalletResourceWithStreamingResponse",
    "UtilsResource",
    "AsyncUtilsResource",
    "UtilsResourceWithRawResponse",
    "AsyncUtilsResourceWithRawResponse",
    "UtilsResourceWithStreamingResponse",
    "AsyncUtilsResourceWithStreamingResponse",
    "Oauth2Resource",
    "AsyncOauth2Resource",
    "Oauth2ResourceWithRawResponse",
    "AsyncOauth2ResourceWithRawResponse",
    "Oauth2ResourceWithStreamingResponse",
    "AsyncOauth2ResourceWithStreamingResponse",
    "KeysendPaymentsResource",
    "AsyncKeysendPaymentsResource",
    "KeysendPaymentsResourceWithRawResponse",
    "AsyncKeysendPaymentsResourceWithRawResponse",
    "KeysendPaymentsResourceWithStreamingResponse",
    "AsyncKeysendPaymentsResourceWithStreamingResponse",
    "EmailPaymentsResource",
    "AsyncEmailPaymentsResource",
    "EmailPaymentsResourceWithRawResponse",
    "AsyncEmailPaymentsResourceWithRawResponse",
    "EmailPaymentsResourceWithStreamingResponse",
    "AsyncEmailPaymentsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import strip_not_given
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["Oauth2Resource", "AsyncOauth2Resource"]


class Oauth2Resource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> Oauth2ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#accessing-raw-response-data-eg-headers
        """
        return Oauth2ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> Oauth2ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#with_streaming_response
        """
        return Oauth2ResourceWithStreamingResponse(self)

    def create_authorization_url(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Create an authorization URL for ZBD Login."""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/v1/oauth2/authorize",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def refresh_token(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Generate a new accessToken for a ZBD Login user."""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/v1/oauth2/token",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve_user_data(
        self,
        *,
        usertoken: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Fetch user-related information about a logged-in ZBD User.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers = {**strip_not_given({"usertoken": usertoken}), **(extra_headers or {})}
        return self._get(
            "/v1/oauth2/user",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve_wallet_data(
        self,
        *,
        usertoken: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Fetch wallet-related information about a logged-in ZBD User.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers = {**strip_not_given({"usertoken": usertoken}), **(extra_headers or {})}
        return self._get(
            "/v1/oauth2/wallet",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncOauth2Resource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncOauth2ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncOauth2ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncOauth2ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#with_streaming_response
        """
        return AsyncOauth2ResourceWithStreamingResponse(self)

    async def create_authorization_url(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Create an authorization URL for ZBD Login."""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/v1/oauth2/authorize",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def refresh_token(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Generate a new accessToken for a ZBD Login user."""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/v1/oauth2/token",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve_user_data(
        self,
        *,
        usertoken: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Fetch user-related information about a logged-in ZBD User.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers = {**strip_not_given({"usertoken": usertoken}), **(extra_headers or {})}
        return await self._get(
            "/v1/oauth2/user",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve_wallet_data(
        self,
        *,
        usertoken: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Fetch wallet-related information about a logged-in ZBD User.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers = {**strip_not_given({"usertoken": usertoken}), **(extra_headers or {})}
        return await self._get(
            "/v1/oauth2/wallet",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class Oauth2ResourceWithRawResponse:
    def __init__(self, oauth2: Oauth2Resource) -> None:
        self._oauth2 = oauth2

        self.create_authorization_url = to_raw_response_wrapper(
            oauth2.create_authorization_url,
        )
        self.refresh_token = to_raw_response_wrapper(
            oauth2.refresh_token,
        )
        self.retrieve_user_data = to_raw_response_wrapper(
            oauth2.retrieve_user_data,
        )
        self.retrieve_wallet_data = to_raw_response_wrapper(
            oauth2.retrieve_wallet_data,
        )


class AsyncOauth2ResourceWithRawResponse:
    def __init__(self, oauth2: AsyncOauth2Resource) -> None:
        self._oauth2 = oauth2

        self.create_authorization_url = async_to_raw_response_wrapper(
            oauth2.create_authorization_url,
        )
        self.refresh_token = async_to_raw_response_wrapper(
            oauth2.refresh_token,
        )
        self.retrieve_user_data = async_to_raw_response_wrapper(
            oauth2.retrieve_user_data,
        )
        self.retrieve_wallet_data = async_to_raw_response_wrapper(
            oauth2.retrieve_wallet_data,
        )


class Oauth2ResourceWithStreamingResponse:
    def __init__(self, oauth2: Oauth2Resource) -> None:
        self._oauth2 = oauth2

        self.create_authorization_url = to_streamed_response_wrapper(
            oauth2.create_authorization_url,
        )
        self.refresh_token = to_streamed_response_wrapper(
            oauth2.refresh_token,
        )
        self.retrieve_user_data = to_streamed_response_wrapper(
            oauth2.retrieve_user_data,
        )
        self.retrieve_wallet_data = to_streamed_response_wrapper(
            oauth2.retrieve_wallet_data,
        )


class AsyncOauth2ResourceWithStreamingResponse:
    def __init__(self, oauth2: AsyncOauth2Resource) -> None:
        self._oauth2 = oauth2

        self.create_authorization_url = async_to_streamed_response_wrapper(
            oauth2.create_authorization_url,
        )
        self.refresh_token = async_to_streamed_response_wrapper(
            oauth2.refresh_token,
        )
        self.retrieve_user_data = async_to_streamed_response_wrapper(
            oauth2.retrieve_user_data,
        )
        self.retrieve_wallet_data = async_to_streamed_response_wrapper(
            oauth2.retrieve_wallet_data,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import voucher_create_params, voucher_redeem_params, voucher_revoke_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["VouchersResource", "AsyncVouchersResource"]


class VouchersResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> VouchersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#accessing-raw-response-data-eg-headers
        """
        return VouchersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> VouchersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#with_streaming_response
        """
        return VouchersResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        amount: str | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Create Voucher

        Args:
          amount: The amount for the Charge -> in millisatoshis

          description: Note or comment for this Charge (visible to payer)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/v1/create-voucher",
            body=maybe_transform(
                {
                    "amount": amount,
                    "description": description,
                },
                voucher_create_params.VoucherCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Get Voucher

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/v0/vouchers/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def redeem(
        self,
        *,
        code: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Redeem Voucher

        Args:
          code: Valid 8-digit ZBD Voucher Code

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/v0/redeem-voucher",
            body=maybe_transform({"code": code}, voucher_redeem_params.VoucherRedeemParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def revoke(
        self,
        *,
        code: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Revoke Voucher

        Args:
          code: Valid 8-digit ZBD Voucher Code

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/v0/revoke-voucher",
            body=maybe_transform({"code": code}, voucher_revoke_params.VoucherRevokeParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncVouchersResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncVouchersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncVouchersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncVouchersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#with_streaming_response
        """
        return AsyncVouchersResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        amount: str | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Create Voucher

        Args:
          amount: The amount for the Charge -> in millisatoshis

          description: Note or comment for this Charge (visible to payer)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/v1/create-voucher",
            body=await async_maybe_transform(
                {
                    "amount": amount,
                    "description": description,
                },
                voucher_create_params.VoucherCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Get Voucher

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            f"/v0/vouchers/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def redeem(
        self,
        *,
        code: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Redeem Voucher

        Args:
          code: Valid 8-digit ZBD Voucher Code

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/v0/redeem-voucher",
            body=await async_maybe_transform({"code": code}, voucher_redeem_params.VoucherRedeemParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def revoke(
        self,
        *,
        code: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Revoke Voucher

        Args:
          code: Valid 8-digit ZBD Voucher Code

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/v0/revoke-voucher",
            body=await async_maybe_transform({"code": code}, voucher_revoke_params.VoucherRevokeParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class VouchersResourceWithRawResponse:
    def __init__(self, vouchers: VouchersResource) -> None:
        self._vouchers = vouchers

        self.create = to_raw_response_wrapper(
            vouchers.create,
        )
        self.retrieve = to_raw_response_wrapper(
            vouchers.retrieve,
        )
        self.redeem = to_raw_response_wrapper(
            vouchers.redeem,
        )
        self.revoke = to_raw_response_wrapper(
            vouchers.revoke,
        )


class AsyncVouchersResourceWithRawResponse:
    def __init__(self, vouchers: AsyncVouchersResource) -> None:
        self._vouchers = vouchers

        self.create = async_to_raw_response_wrapper(
            vouchers.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            vouchers.retrieve,
        )
        self.redeem = async_to_raw_response_wrapper(
            vouchers.redeem,
        )
        self.revoke = async_to_raw_response_wrapper(
            vouchers.revoke,
        )


class VouchersResourceWithStreamingResponse:
    def __init__(self, vouchers: VouchersResource) -> None:
        self._vouchers = vouchers

        self.create = to_streamed_response_wrapper(
            vouchers.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            vouchers.retrieve,
        )
        self.redeem = to_streamed_response_wrapper(
            vouchers.redeem,
        )
        self.revoke = to_streamed_response_wrapper(
            vouchers.revoke,
        )


class AsyncVouchersResourceWithStreamingResponse:
    def __init__(self, vouchers: AsyncVouchersResource) -> None:
        self._vouchers = vouchers

        self.create = async_to_streamed_response_wrapper(
            vouchers.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            vouchers.retrieve,
        )
        self.redeem = async_to_streamed_response_wrapper(
            vouchers.redeem,
        )
        self.revoke = async_to_streamed_response_wrapper(
            vouchers.revoke,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["VoucherCreateParams"]


class VoucherCreateParams(TypedDict, total=False):
    amount: str
    """The amount for the Charge -> in millisatoshis"""

    description: str
    """Note or comment for this Charge (visible to payer)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import withdrawal_request_create_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["WithdrawalRequestsResource", "AsyncWithdrawalRequestsResource"]


class WithdrawalRequestsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> WithdrawalRequestsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#accessing-raw-response-data-eg-headers
        """
        return WithdrawalRequestsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> WithdrawalRequestsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#with_streaming_response
        """
        return WithdrawalRequestsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        amount: str | NotGiven = NOT_GIVEN,
        callback_url: str | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        expires_in: float | NotGiven = NOT_GIVEN,
        internal_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Start creating Bitcoin voucher QR codes.

        Args:
          amount: The amount for the Withdrawal Request -> in millisatoshis

          callback_url: The endpoint ZBD will POST Charge updates to

          description: Note or comment for this Withdrawal Request

          expires_in: Time until Withdrawal Request expiration -> in seconds

          internal_id: Open metadata string property

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/v0/withdrawal-requests",
            body=maybe_transform(
                {
                    "amount": amount,
                    "callback_url": callback_url,
                    "description": description,
                    "expires_in": expires_in,
                    "internal_id": internal_id,
                },
                withdrawal_request_create_params.WithdrawalRequestCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Retrieve all data about a single Withdrawal Request.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/v0/withdrawal-requests/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncWithdrawalRequestsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncWithdrawalRequestsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncWithdrawalRequestsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncWithdrawalRequestsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/zbdpay/zbd-payments-python-sdk#with_streaming_response
        """
        return AsyncWithdrawalRequestsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        amount: str | NotGiven = NOT_GIVEN,
        callback_url: str | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        expires_in: float | NotGiven = NOT_GIVEN,
        internal_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Start creating Bitcoin voucher QR codes.

        Args:
          amount: The amount for the Withdrawal Request -> in millisatoshis

          callback_url: The endpoint ZBD will POST Charge updates to

          description: Note or comment for this Withdrawal Request

          expires_in: Time until Withdrawal Request expiration -> in seconds

          internal_id: Open metadata string property

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/v0/withdrawal-requests",
            body=await async_maybe_transform(
                {
                    "amount": amount,
                    "callback_url": callback_url,
                    "description": description,
                    "expires_in": expires_in,
                    "internal_id": internal_id,
                },
                withdrawal_request_create_params.WithdrawalRequestCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Retrieve all data about a single Withdrawal Request.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            f"/v0/withdrawal-requests/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class WithdrawalRequestsResourceWithRawResponse:
    def __init__(self, withdrawal_requests: WithdrawalRequestsResource) -> None:
        self._withdrawal_requests = withdrawal_requests

        self.create = to_raw_response_wrapper(
            withdrawal_requests.create,
        )
        self.retrieve = to_raw_response_wrapper(
            withdrawal_requests.retrieve,
        )


class AsyncWithdrawalRequestsResourceWithRawResponse:
    def __init__(self, withdrawal_requests: AsyncWithdrawalRequestsResource) -> None:
        self._withdrawal_requests = withdrawal_requests

        self.create = async_to_raw_response_wrapper(
            withdrawal_requests.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            withdrawal_requests.retrieve,
        )


class WithdrawalRequestsResourceWithStreamingResponse:
    def __init__(self, withdrawal_requests: WithdrawalRequestsResource) -> None:
        self._withdrawal_requests = withdrawal_requests

        self.create = to_streamed_response_wrapper(
            withdrawal_requests.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            withdrawal_requests.retrieve,
        )


class AsyncWithdrawalRequestsResourceWithStreamingResponse:
    def __init__(self, withdrawal_requests: AsyncWithdrawalRequestsResource) -> None:
        self._withdrawal_requests = withdrawal_requests

        self.create = async_to_streamed_response_wrapper(
            withdrawal_requests.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            withdrawal_requests.retrieve,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["InternalTransferInitiateParams"]


class InternalTransferInitiateParams(TypedDict, total=False):
    amount: str
    """The amount to be transferred -> in millisatoshis"""

    receiver_wallet_id: Annotated[str, PropertyInfo(alias="receiverWalletId")]
    """The Wallet ID of the recipient Project"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["LightningAddressCreateChargeParams"]


class LightningAddressCreateChargeParams(TypedDict, total=False):
    amount: str
    """The amount for the Charge -> in millisatoshis"""

    description: str
    """Note or comment of this Charge"""

    lnaddress: str
    """The Lightning Address of the intended recipient"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .voucher_create_params import VoucherCreateParams as VoucherCreateParams
from .voucher_redeem_params import VoucherRedeemParams as VoucherRedeemParams
from .voucher_revoke_params import VoucherRevokeParams as VoucherRevokeParams
from .email_payment_send_params import EmailPaymentSendParams as EmailPaymentSendParams
from .keysend_payment_send_params import KeysendPaymentSendParams as KeysendPaymentSendParams
from .gamertag_send_payment_params import GamertagSendPaymentParams as GamertagSendPaymentParams
from .gamertag_create_charge_params import GamertagCreateChargeParams as GamertagCreateChargeParams
from .lightning_payment_send_params import LightningPaymentSendParams as LightningPaymentSendParams
from .lightning_charge_create_params import LightningChargeCreateParams as LightningChargeCreateParams
from .withdrawal_request_create_params import WithdrawalRequestCreateParams as WithdrawalRequestCreateParams
from .internal_transfer_initiate_params import InternalTransferInitiateParams as InternalTransferInitiateParams
from .util_decode_lightning_charge_params import UtilDecodeLightningChargeParams as UtilDecodeLightningChargeParams
from .lightning_address_send_payment_params import (
    LightningAddressSendPaymentParams as LightningAddressSendPaymentParams,
)
from .lightning_static_charge_create_params import (
    LightningStaticChargeCreateParams as LightningStaticChargeCreateParams,
)
from .lightning_static_charge_update_params import (
    LightningStaticChargeUpdateParams as LightningStaticChargeUpdateParams,
)
from .lightning_address_create_charge_params import (
    LightningAddressCreateChargeParams as LightningAddressCreateChargeParams,
)
